DataPackage class

Constructors

DataPackage({required String? eventsJson, required String? eventsSign, required int? signTime, required String? signVersion})

Properties

eventsJson → String?
final
eventsSign → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signTime → int?
final
signVersion → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited